@@ -1,8 +1,8 @@
-## ----setup, include=FALSE-----------------------------------------------------
+## ----setup--------------------------------------------------------------------
 source("https://raw.githubusercontent.com/Flavjack/inti/master/pkgdown/favicon/docs.r")
 knitr::opts_chunk$set(echo = TRUE)
 
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tibble(
   Standart = "$H^2=\\frac{\\sigma_g^2}{\\sigma_p^2}=\\frac{\\Delta G}{S}$",
   Cullis = "$H_{Cullis}^2=1-\\frac{\\overline{V}_{\\Delta..}^{^{BLUP}}}{2\\cdot\\sigma_g^2}$",
@@ -10,21 +10,21 @@ tibble(
   ) %>% 
   kable(caption = "Differentes heritability calculation")
 
-## ----pkgs, echo=TRUE----------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(inti)
 
-## ----fig.width= 7, fig.height=5-----------------------------------------------
- dt <- potato
- hr <- H2cal(data = dt
-            , trait = "stemdw"
-            , gen.name = "geno"
-            , rep.n = 5
-            , fixed.model = "0 + (1|bloque) + geno"
-            , random.model = "1 + (1|bloque) + (1|geno)"
-            , emmeans = TRUE
-            , plot_diag = TRUE
-            , outliers.rm = TRUE
-            )
+## -----------------------------------------------------------------------------
+dt <- inti::potato
+hr <- H2cal(data = dt
+          , trait = "stemdw"
+          , gen.name = "geno"
+          , rep.n = 5
+          , fixed.model = ~ 0 + (1|bloque) + geno
+          , random.model = ~ 1 + (1|bloque) + (1|geno)
+          , emmeans = TRUE
+          , plot_diag = FALSE
+          , outliers.rm = TRUE
+          )
 
 ## -----------------------------------------------------------------------------
 hr$model %>% summary()
@@ -44,6 +44,6 @@ hr$outliers$fixed %>% kable(caption = "Outliers fixed model")
 ## -----------------------------------------------------------------------------
 hr$outliers$random %>% kable(caption = "Outliers random model")
 
-## ----references, echo=FALSE---------------------------------------------------
+## -----------------------------------------------------------------------------
 if(!file.exists("files/pkgs.bib")){write_bib(c(.packages()),'files/pkgs.bib')}
 
